
application:setFps(60)
application:setBackgroundColor(0x000000)
stage:setOrientation(Stage.LANDSCAPE_LEFT)

-- texture pack
local pack = TexturePack.new("images/coin.txt", "images/coin.png")

-- create bitmaps for animation
local frames = {}
for i = 1, 10 do
  frames[#frames + 1] =  Bitmap.new(pack:getTextureRegion("coin" .. i .. ".png"))
end

-- our movieclip
local clip = MovieClip.new({
  { 1, 10, frames[1]},
  {10, 20, frames[2]},
  {20, 30, frames[3]},
  {30, 40, frames[4]},
  {40, 50, frames[5]},
  {50, 60, frames[6]},
  {60, 70, frames[7]},
  {70, 80, frames[8]},
  {80, 90, frames[9]},
  {90, 100, frames[10]},
})

-- our extra vars
clip.paused = false
clip.timer = 0

-- display and start playback
clip:setAnchorPoint(0.5, 0.5)
clip:setPosition(240, 160)
clip:setGotoAction(100, 1) -- looping animation
stage:addChild(clip)
clip:gotoAndPlay(1)

-- just so we can see what frame it is currently on
local info = TextField.new(nil, "")
info:setPosition(24, 32)
info:setTextColor(0xc0c0c0)
info:setScale(2)
stage:addChild(info)

local function onEnterFrame(e)
  local dt = e.deltaTime

  if clip.paused then
    local timer = clip.timer + dt -- increment timer
    if timer >= 1 then -- after one second we resume playback
      clip.paused = false
      clip:play() -- resume playback from current frame
    end
    clip.timer = timer
  end

  -- update info text
  local frame = clip:getFrame()
  info:setText(frame)
end

local function touchEnd()
  if not clip.paused then
    -- set clip paused, reset timer, and stop playback at current frame
    clip.timer = 0
    clip.paused = true
    clip:stop()
  end
end

stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)
stage:addEventListener(Event.TOUCHES_END, touchEnd)
